Binder<T> class

Inheritance

Constructors

Binder({Key? key, required Widget child, InitBuilder<T>? init, bool global = true, bool autoRemove = true, bool assignId = false, bool lazy = true, void initState(BindElement<T> state)?, Object filter(T value)?, String? tag, void dispose(BindElement<T> state)?, Object? id, void didChangeDependencies(BindElement<T> state)?, void didUpdateWidget(Binder<T> oldWidget, BindElement<T> state)?, InstanceCreateBuilderCallback? create})
Create an inherited widget that updates its dependents when controller sends notifications.
const

Properties

assignId → bool
final
autoRemove → bool
final
child → Widget
The widget below this widget in the tree.
finalinherited
create → InstanceCreateBuilderCallback?
final
didChangeDependencies → void Function(BindElement<T> state)?
final
didUpdateWidget → void Function(Binder<T> oldWidget, BindElement<T> state)?
final
dispose → void Function(BindElement<T> state)?
final
filter → Object Function(T value)?
final
global → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → Object?
final
init → InitBuilder<T>?
final
initState → void Function(BindElement<T> state)?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lazy → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
final

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant Binder<T> oldWidget) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited